/*
 * e-passwords.h
 *
 * Copyright (C) 2001 Ximian, Inc.
 */

/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU Lesser General Public
 * License as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA.
 */

#ifndef _E_PASSWORD_H_
#define _E_PASSWORD_H_

#include <glib.h>
#include <gtk/gtkwindow.h>

G_BEGIN_DECLS

/**
 * EPasswordsRememberType:
 * @E_PASSWORDS_REMEMBER_NEVER:
 * 	Do not remember the password.
 * @E_PASSWORDS_REMEMBER_SESSION:
 * 	Remember the password for this session only.
 * @E_PASSWORDS_REMEMBER_FOREVER:
 * 	Remember the password across multiple sessions.
 * @E_PASSWORDS_REMEMBER_MASK:
 * 	Mask value separates the mutually-exclusive values
 * 	of the enumeration from the flags.
 * @E_PASSWORDS_SECRET:
 * 	Do not show the password as it's being typed.
 * @E_PASSWORDS_REPROMPT:
 * 	Populate the dialog with the current password (if one exists).
 * @E_PASSWORDS_ONLINE:
 * 	Only prompt the user for a password if we're online.
 * @E_PASSWORDS_DISABLE_REMEMBER:
 * 	Disable the "remember password" option on the dialog.
 * @E_PASSWORDS_PASSPHRASE:
 * 	Ask for a passphrase instead of a password.
 **/
typedef enum {
	E_PASSWORDS_REMEMBER_NEVER,
	E_PASSWORDS_REMEMBER_SESSION,
	E_PASSWORDS_REMEMBER_FOREVER,
	E_PASSWORDS_REMEMBER_MASK = 0xf,

	/* flags */
	E_PASSWORDS_SECRET           = 1 << 8,
	E_PASSWORDS_REPROMPT         = 1 << 9,
	E_PASSWORDS_ONLINE           = 1 << 10,
	E_PASSWORDS_DISABLE_REMEMBER = 1 << 11,
	E_PASSWORDS_PASSPHRASE       = 1 << 12,
} EPasswordsRememberType;

#ifndef EDS_DISABLE_DEPRECATED
void		e_passwords_init		(void);
void		e_passwords_shutdown		(void);
void		e_passwords_cancel		(void);
#endif
void		e_passwords_set_online		(gboolean online);
void		e_passwords_remember_password	(const gchar *component,
						 const gchar *key);
void		e_passwords_add_password	(const gchar *key,
						 const gchar *password);
gchar *		e_passwords_get_password	(const gchar *component,
						 const gchar *key);
void		e_passwords_forget_password	(const gchar *component,
						 const gchar *key);
void		e_passwords_forget_passwords	(void);
void		e_passwords_clear_passwords	(const gchar *component);
gchar *		e_passwords_ask_password	(const gchar *title, 
						 const gchar *component,
						 const gchar *key,
						 const gchar *prompt,
						 EPasswordsRememberType remember_type,
						 gboolean *remember,
						 GtkWindow *parent);

G_END_DECLS

#endif /* _E_PASSWORD_H_ */
